%{?dist: %{expand: %%define dist_%dist 1}}

Summary:     Anonymizing overlay network for TCP (The onion router)
Name:        tor
Version:     0.1.2.18
Release:     11%{?dist:.%{dist}}%{?pext}
License:     BSD
Group:       System Environment/Daemons
Source0:     http://%{name}.eff.org/dist/%{name}-%{version}.tar.gz
Source1:     %{name}.init
Source2:     %{name}.logrotate
Source3:     %{name}.sysconfig
Patch0:      %{name}-0.1.2.13-config.patch
Patch1:      %{name}-0.1.1.20-connection.patch
Patch2:      %{name}-0.1.2.13-accounting.patch
Patch3:      %{name}-0.1.2.13-build-x86_64.patch
URL:         http://%{name}.eff.org/
Buildroot:   /var/tmp/%{name}-root
Vendor:      Roger Dingledine <arma@seul.org>
Packager:    Peter Pramberger <peter.pramberger@member.fsf.org>
Provides:    %{name}%{?pext}
Requires:    libevent openssl097
Prereq:      fileutils glibc shadow-utils
BuildPrereq: fileutils glibc-devel gcc make
BuildPrereq: libevent-devel openssl097-devel
ExclusiveOS: linux


%description
Tor is a connection-based low-latency anonymous communication
system. Applications connect to the local Tor proxy using the
SOCKS protocol. The local proxy chooses a path through a set of
relays, in which each relay knows its predecessor and successor,
but no others. Traffic flowing down the circuit is unwrapped by
a symmetric key at each relay, which reveals the downstream relay.

Warnings: Tor does no protocol cleaning. That means there is a
danger that application protocols and associated programs can be
induced to reveal information about the initiator. Tor depends on
Privoxy and similar protocol cleaners to solve this problem. This
is alpha code, and is even more likely than released code to have
anonymity-spoiling bugs. The present network is very small, which
further reduces the strength of the anonymity provided. Tor is not
presently suitable for high-stakes anonymity.


%prep
%setup -q
%patch0 -p1 -b .config
%patch1 -p1 -b .conn
%patch2 -p1 -b .acct
%patch3 -p1 -b .x86_64

# Fix package deps
find contrib -type f -exec %{__chmod} a-x {} \;

# Prepare docs
%{__cp} -r doc/spec .


%build
%configure \
	CFLAGS="${CFLAGS} -DOPENSSL_NO_KRB5" \
	--enable-debug                       \
	--enable-eventdns                    \
	--with-ssl-dir=%{_prefix}            \
	--with-libevent-dir=%{_prefix}       \
	--with-tor-user=%{name}              \
	--with-tor-group=%{name}

%{__make} \
	all


%install
[ -n "${RPM_BUILD_ROOT}" -a "${RPM_BUILD_ROOT}" != "/" ] && %{__rm} -rf ${RPM_BUILD_ROOT}
%{__mkdir_p} ${RPM_BUILD_ROOT}%{_initrddir}
%{__mkdir_p} ${RPM_BUILD_ROOT}%{_sysconfdir}/{logrotate.d,sysconfig}
%{__mkdir_p} ${RPM_BUILD_ROOT}%{_sbindir}
%{__mkdir_p} ${RPM_BUILD_ROOT}%{_localstatedir}/{lib,log,run}/%{name}

%{__make} \
	DESTDIR=${RPM_BUILD_ROOT} \
	install

%{__mv} ${RPM_BUILD_ROOT}%{_bindir}/%{name} ${RPM_BUILD_ROOT}%{_sbindir}

%{__install} -m 0755 %{SOURCE1} ${RPM_BUILD_ROOT}%{_initrddir}/%{name}
%{__install} -m 0644 %{SOURCE2} ${RPM_BUILD_ROOT}%{_sysconfdir}/logrotate.d/%{name}
%{__install} -m 0644 %{SOURCE3} ${RPM_BUILD_ROOT}%{_sysconfdir}/sysconfig/%{name}


%pre
if ! %{__id} -g %{name} >/dev/null 2>&1; then
  groupadd -r %{name}
fi
if ! %{__id} -u %{name} >/dev/null 2>&1; then
  useradd  -g %{name} -G %{name}            \
	   -d %{_localstatedir}/lib/%{name} \
	   -r -s /sbin/nologin %{name}
fi


%post
if [ $1 = 1 ]; then
  chkconfig --add %{name}
  chkconfig %{name} on
fi
if [ -f %{_localstatedir}/lock/subsys/%{name} ]; then
  %{_initrddir}/%{name} restart
fi


%preun
if [ $1 = 0 ]; then
  chkconfig %{name} off
  chkconfig --del %{name}
  if [ -f %{_localstatedir}/lock/subsys/%{name} ]; then
    %{_initrddir}/%{name} stop
  fi
fi


%clean
[ -n "${RPM_BUILD_ROOT}" -a "${RPM_BUILD_ROOT}" != "/" ] && %{__rm} -rf ${RPM_BUILD_ROOT}


%files
%defattr(-,root,root)
%doc AUTHORS ChangeLog INSTALL LICENSE README
%doc ReleaseNotes doc/HACKING doc/TODO
%doc --parents spec/*.txt contrib/exitlist contrib/*.py
%{_initrddir}/*
%config(noreplace) %{_sysconfdir}/logrotate.d/*
%config(noreplace) %{_sysconfdir}/sysconfig/*
%attr(750,root,%{name}) %dir %{_sysconfdir}/%{name}
%attr(640,root,%{name}) %config(noreplace) %{_sysconfdir}/%{name}/*.conf
%{_sysconfdir}/%{name}/*.sample
%{_bindir}/*
%{_sbindir}/*
%{_mandir}/man1/*
%attr(750,%{name},%{name}) %dir %{_localstatedir}/lib/%{name}
%attr(750,%{name},%{name}) %dir %{_localstatedir}/log/%{name}
%attr(750,%{name},%{name}) %dir %{_localstatedir}/run/%{name}


%changelog
* Wed Oct 31 2007 peter.pramberger@member.fsf.org 0.1.2.18-11
- new version (0.1.2.18)

* Tue Oct 09 2007 peter.pramberger@member.fsf.org 0.1.2.17-11
- new libevent version (1.3e)

* Fri Aug 31 2007 peter.pramberger@member.fsf.org 0.1.2.17-10
- new version (0.1.2.17)

* Mon Aug 06 2007 peter.pramberger@member.fsf.org 0.1.2.16-10
- new version (0.1.2.16)

* Wed Jul 25 2007 peter.pramberger@member.fsf.org 0.1.2.15-10
- new version (0.1.2.15)

* Tue May 29 2007 peter.pramberger@member.fsf.org 0.1.2.14-10
- new version (0.1.2.14)

* Fri May 11 2007 peter.pramberger@member.fsf.org 0.1.2.13-10
- new version (0.1.2.13)
- updated config patch
- updated accounting patch
- updated init script to verify config before start/reload

* Mon Jan 22 2007 peter.pramberger@member.fsf.org 0.1.1.26-10
- fixed linkage problem on x86_64

* Thu Jan 18 2007 peter.pramberger@member.fsf.org 0.1.1.26-9
- rebuild for new libevent version (1.2a)

* Mon Dec 18 2006 peter.pramberger@member.fsf.org 0.1.1.26-8
- new version (0.1.1.26)

* Thu Nov 09 2006 peter.pramberger@member.fsf.org 0.1.1.25-8
- new version (0.1.1.25)

* Sun Oct 08 2006 peter.pramberger@member.fsf.org
- new version (0.1.1.24)

* Fri Sep 08 2006 peter.pramberger@member.fsf.org
- rebuild for new libevent version (1.1b)

* Thu Aug 24 2006 peter.pramberger@member.fsf.org
- added resolver patch
- updated init script to remove localdomain

* Fri Aug 04 2006 peter.pramberger@member.fsf.org
- new version (0.1.1.23)

* Sat Jul 08 2006 peter.pramberger@member.fsf.org
- new version (0.1.1.22)

* Mon Jun 12 2006 peter.pramberger@member.fsf.org
- new version (0.1.1.21)

* Wed May 24 2006 peter.pramberger@member.fsf.org
- new version (0.1.1.20)
- updated config patch
- updated TCP keepalive patch
- updated accounting patch

* Tue Feb 21 2006 peter.pramberger@member.fsf.org
- new version (0.1.0.17)

* Wed Jan 04 2006 peter.pramberger@member.fsf.org
- new version (0.1.0.16)

* Sun Oct 30 2005 peter.pramberger@member.fsf.org
- fixed typo in logrotate config

* Sat Oct 29 2005 peter.pramberger@member.fsf.org
- updated config patch
- added TCP keepalive patch
- added accounting patch
- updated init script for slow shutdown

* Wed Oct 26 2005 peter.pramberger@member.fsf.org
- created

